{
  pkgs,
  inputs,
  ...
}:
{
  imports = [
    ./hardware-configuration.nix
    inputs.disko.nixosModules.disko
    inputs.nixos-hardware.nixosModules.common-cpu-intel
    ./disko.nix
  ];

  hardware.graphics = {
    enable = true;
    enable32Bit = true;
  };

  boot = {
    consoleLogLevel = 3;
    kernelParams = [
      "quiet"
      "splash"
      "boot.shell_on_fail"
      "udev.log_priority=3"
      "rd.systemd.show_status=auto"
    ];

    initrd = {
      systemd.enable = true;
      verbose = false;
    };
    kernelPackages = pkgs.linuxPackages_latest;
    plymouth =
      let
        themeName = "lone";
      in
      {
        enable = true;
        theme = themeName;
        themePackages = with pkgs; [
          (adi1090x-plymouth-themes.override {
            selected_themes = [ themeName ];
          })
        ];
      };
  };

  zramSwap.enable = true;
  networking.hostName = "lenar";

  services.power-profiles-daemon.enable = false;
  services.tlp = {
    enable = true;
    settings = {
      DEVICES_TO_DISABLE_ON_STARTUP = "bluetooth";
    };
  };

  # My own modules configuration
  krop = {
    audio = {
      enable = true;
    };
    ide = {
      enable = true;
      install-pycharm = true;
      install-goland = true;
      install-webstorm = true;
      install-datagrip = true;
      install-clion = true;
    };
    python = {
      enable = true;
      install-additional = true;
    };
    cli = {
      enable = true;
      install-k8s-tools = true;
      install-cloud-cli = true;
    };
    docker = {
      enable = true;
      changeDefaultNetwork = true;
    };
    waydroid.enable = true;
    podman.enable = true;
    de.gnome = {
      enable = true;
    };
  };

  systemd.services.configure-mic-leds = rec {
    wantedBy = [ "sound.target" ];
    after = wantedBy;
    serviceConfig.Type = "oneshot";
    script = ''
      echo off > /sys/class/sound/ctl-led/mic/mode
    '';
  };

  home-manager = {
    users = {
      "krop" = import ./home.nix;
    };
  };
}
